@@ -24,6 +24,7 @@
 #include <sys/types.h>
 #include <glib.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include "gtkhtml-compat.h"
 #include "gtkhtml-stream.h"
@@ -86,11 +87,17 @@ gtk_html_stream_vprintf (GtkHTMLStream *stream,
 	size_t len;
 	char *buf = NULL;
 	char *mbuf = NULL;
+	char *result_string = NULL;
 	int rv;
 	va_list ap_copy;
 
 	G_VA_COPY (ap_copy, ap);
-	len = g_printf_string_upper_bound (format, ap_copy);
+
+	result_string = g_strdup_vprintf (format, ap_copy);
+	g_return_val_if_fail (result_string != NULL, 0);
+
+	len = strlen (result_string);
+	g_free (result_string);
 
 	if (len < 8192)
 		buf = alloca (len);
